==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Metre a jou touti li URL',
	'actualiser_toutes_explication' => 'Poudès recarculà li URL.
		S’una URL a changiat, una nouvèla intrada serà creada (sensa perdre li URL jà
		presenti e sensa afetà li URL definidi manualamen).',

	// B
	'bouton_supprimer_url' => 'Suprimà aquela URL',

	// E
	'erreur_arbo_2_segments_max' => 'Noun poudès utilisà mai de doui segment d’URL per un ouget',
	'erreur_config_url_forcee' => 'La counfiguracioun dei URL es fourçada en lou fichié <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestioun avançada dei URL vi permete d’édità l’URL dei pàgina de cada ouget editourial, e de gerà l’istòrica de la siéu evoulucioun.',

	// I
	'icone_configurer_urls' => 'Counfigurà li URL',
	'icone_controler_urls' => 'URL significativi',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Ouget',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'URL nouvela',
	'label_url_minuscules_0' => 'Counservà la cassa dóu titre',
	'label_url_minuscules_1' => 'Fouòrça li URL en minùscula',
	'label_url_permanente' => 'Ferouià aquela URL (mìnga metuda a jou après edicioun de l’ouget)',
	'label_url_sep_id' => 'Caracter da desseparà lou nùmero ajustat en cas d’URL duplicadi',
	'label_urls_activer_controle_oui' => 'Ativà la gestioun avançada dei URL',
	'label_urls_nb_max_car' => 'Noumbre massimoum de caracter',
	'label_urls_nb_min_car' => 'Noumbre minimum de caracter',
	'liberer_url' => 'Liberà',
	'liste_des_urls' => 'Touti li URL',

	// T
	'texte_type_urls' => 'Poudès chausì aquì souta lou mòdou de carcul de l’adressa dei pàgina.',
	'texte_type_urls_attention' => 'Mèfi, aqueu reglage founciounerà que se lou fichié @htaccess@ es ben instalat a la raïs dau sit.',
	'texte_urls_nb_max_car' => 'Se lou titre es mai lonc, serà coupat.',
	'texte_urls_nb_min_car' => 'Se lou titre es mai court, es lou siéu Nùmero identificant que serà utilisat.',
	'titre_gestion_des_urls' => 'Gestioun dei URL',
	'titre_type_arbo' => 'URL Arbouressenti',
	'titre_type_html' => 'URL Ouget HTML',
	'titre_type_libres' => 'URL Lìberou',
	'titre_type_page' => 'URL Pàgina',
	'titre_type_propres' => 'URL Propri',
	'titre_type_propres2' => 'URL Propri+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URL Propri en query-string',
	'titre_type_simple' => 'URL Simpli',
	'titre_type_standard' => 'URL Istòriqui',
	'titre_type_urls' => 'Tìpou d’adressa URL',
	'tout_voir' => 'Veire touti li URL',

	// U
	'url_ajout_impossible' => 'Una errour s’es prouducha. L’URL noun a pouscut estre registrada.',
	'url_ajoutee' => 'L’URL es estada ajustada',

	// V
	'verifier_url_nettoyee' => 'L’URL es estada courregida, poudès verificà denant de la registrà.',
	'verrouiller_url' => 'Ferouià'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Metre a jou touti li URL',
	'actualiser_toutes_explication' => 'Poudès recarculà li URL.
		S’una URL a changiat, una nouvèla intrada serà creada (sensa perdre li URL jà
		presenti e sensa afetà li URL definidi manualamen).',

	// B
	'bouton_supprimer_url' => 'Suprimà aquela URL',

	// E
	'erreur_arbo_2_segments_max' => 'Noun poudès utilisà mai de doui segment d’URL per un ouget',
	'erreur_config_url_forcee' => 'La counfiguracioun dei URL es fourçada en lou fichié <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestioun avançada dei URL vi permete d’édità l’URL dei pàgina de cada ouget editourial, e de gerà l’istòrica de la siéu evoulucioun.',

	// I
	'icone_configurer_urls' => 'Counfigurà li URL',
	'icone_controler_urls' => 'URL significativi',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Ouget',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'URL nouvela',
	'label_url_minuscules_0' => 'Counservà la cassa dóu titre',
	'label_url_minuscules_1' => 'Fouòrça li URL en minùscula',
	'label_url_permanente' => 'Ferouià aquela URL (mìnga messa a jou après edicioun de l’ouget)',
	'label_url_sep_id' => 'Caracter da desseparà lou nùmero ajustat en cas d’URL duplicadi',
	'label_urls_activer_controle_oui' => 'Ativà la gestioun avançada dei URL',
	'label_urls_nb_max_car' => 'Noumbre massimoum de caracter',
	'label_urls_nb_min_car' => 'Noumbre minimum de caracter',
	'liberer_url' => 'Liberà',
	'liste_des_urls' => 'Touti li URL',

	// T
	'texte_type_urls' => 'Poudès chausì aquì souta lou mòdou de carcul de l’adressa dei pàgina.',
	'texte_type_urls_attention' => 'Mèfi, aqueu reglage founciounerà que se lou fichié @htaccess@ es ben instalat a la raïs dau sit.',
	'texte_urls_nb_max_car' => 'Se lou titre es mai lonc, serà coupat.',
	'texte_urls_nb_min_car' => 'Se lou titre es mai court, es lou siéu Nùmero identificant que serà utilisat.',
	'titre_gestion_des_urls' => 'Gestioun dei URL',
	'titre_type_arbo' => 'URL Arbouressenti',
	'titre_type_html' => 'URL Ouget HTML',
	'titre_type_libres' => 'URL Lìberou',
	'titre_type_page' => 'URL Pàgina',
	'titre_type_propres' => 'URL Propri',
	'titre_type_propres2' => 'URL Propri+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URL Propri en query-string',
	'titre_type_simple' => 'URL Simpli',
	'titre_type_standard' => 'URL Istòriqui',
	'titre_type_urls' => 'Tìpou d’adressa URL',
	'tout_voir' => 'Veire touti li URL',

	// U
	'url_ajout_impossible' => 'Una errour s’es prouducha. L’URL noun a pouscut estre registrada.',
	'url_ajoutee' => 'L’URL es estada ajustada',

	// V
	'verifier_url_nettoyee' => 'L’URL es estada courregida, poudès verificà denant de la registrà.',
	'verrouiller_url' => 'Ferouià'
);

?>
